@@ -33,9 +33,9 @@ class HttpResult(BaseModel, Generic[T]):
 	    Result.server_error(exc=HTTPException(status=500, detail="Internal server error."))
     """
     status: ActionStatus
-    data: Optional[T]
-    exc: HTTPException
-    detail: Optional[str]
+    data: Optional[T] = None
+    exc: Optional[HTTPException] = None
+    detail: Optional[str] = None
 
     class Config:
         arbitrary_types_allowed = True
@@ -47,19 +47,18 @@ class HttpResult(BaseModel, Generic[T]):
     def is_failure(self):
         return not self.is_success()
 
-
-
     @classmethod
     def success(cls, data: Optional[T] = None, detail: Optional[str] = None):
         return HttpResult(status=ActionStatus.success, data=data, detail=detail)
 
     @classmethod
-    def failure(cls, exc: HTTPException):
-        raise exc
+    def failure(cls, status_code: int, detail: Optional[str] = None):
+        exc = HTTPException(status_code=status_code, detail=detail)
+        return HttpResult(status=ActionStatus.failure, exc=exc)
 
     @classmethod
     def server_error(
-        cls,
-        exc: HTTPException = HTTPException(status_code=500, detail="Internal server error")
+            cls,
+            exc: HTTPException = HTTPException(status_code=500, detail="Internal server error")
     ):
         raise exc
